#Parameter Estimation
library(readr)
simdata <- read_csv("C:/simdata.csv")
simdata$S.delta<- c(simdata$S[-1],0)-simdata$S
simdata$It.delta<- c(simdata$It[-1],0)-simdata$It
simdata$Ih.delta<- c(simdata$Ih[-1],0)-simdata$Ih
simdata$C.delta<- c(simdata$C[-1],0)-simdata$C
simdata$Dt.delta<- c(simdata$Dt[-1],0)-simdata$Dt
simdata$Dh.delta<- c(simdata$Dh[-1],0)-simdata$Dh
simdata$Dc.delta<- c(simdata$Dc[-1],0)-simdata$Dc
simdata$Rt.delta<- c(simdata$Rt[-1],0)-simdata$Rt
simdata$Rc.delta<- c(simdata$Rc[-1],0)-simdata$Rc
simdata<- simdata[-nrow(simdata),]
mu <- 1/70
N <- 53145033
for (j in 1:nrow(simdata)) {
  simdata$lambda.est[j]<- (simdata$S.delta[j]+simdata$It.delta[j]+simdata$Rt.delta[j]+
                             simdata$Dt.delta[j]+simdata$Ih.delta[j]+simdata$C.delta[j]+
                             simdata$Rc.delta[j]+simdata$Dc.delta[j]+simdata$Dh.delta[j]+
                             mu*(simdata$Rt[j]+simdata$It[j]+simdata$Rc[j]+
                                   simdata$C[j]+simdata$Ih[j]+simdata$S[j]))
  simdata$betaT.est[j]<- (simdata$It.delta[j]+simdata$Rt.delta[j]+simdata$Dt.delta[j]+
                            mu*(simdata$It[j]+simdata$Rt[j]))/(simdata$S[j]*simdata$It[j])
  simdata$betaH.est[j]<- (simdata$Ih.delta[j]+simdata$C.delta[j]+simdata$Rc.delta[j]+
                            simdata$Dc.delta[j]+simdata$Dh.delta[j]+
                            mu*(simdata$Rc[j]+simdata$C[j]+simdata$Ih.delta[j]))/(simdata$S[j]*simdata$Ih[j])
  simdata$epsilon.est[j]<- (simdata$C.delta[j]+simdata$Rc.delta[j]+simdata$Dc.delta[j]+
                              mu*(simdata$Rc[j]+simdata$C[j]))/(simdata$It[j]*simdata$Ih[j])
  simdata$gammaT.est[j]<- (simdata$Rt.delta[j]+mu*simdata$Rt[j])/(simdata$It[j])
  simdata$gammaC.est[j]<- (simdata$Rc.delta[j]+mu*simdata$Rc[j])/(simdata$C[j])
  simdata$thetaT.est[j]<- (simdata$Dt.delta[j])/(simdata$It[j])
  simdata$thetaH.est[j]<- (simdata$Dh.delta[j])/(simdata$Ih[j])
  simdata$thetaC.est[j]<- (simdata$Dc.delta[j])/(simdata$C[j])
  
}
#estimating using the method of moments
print(lambda.hatMM<- mean(simdata$lambda.est)/N)
print(betaT.hatMM<- N*mean(simdata$betaT.est))
print(betaH.hatMM<- N*mean(simdata$betaH.est))
print(epsilon.hatMM<- mean(simdata$epsilon.est))
print(gammaT.hatMM<- mean(simdata$gammaT.est))
print(gammaC.hatMM<- mean(simdata$gammaC.est))
print(thetaT.hatMM<- mean(simdata$thetaT.est))
print(thetaH.hatMM<- mean(simdata$thetaH.est))
print(thetaC.hatMM<- mean(simdata$thetaC.est))



#30-year Simulation
set.seed(191962)
N<- 53145033
mu <- 1/70
lambda <- 0.0280
betaT <- 0.3859
betaH <- 0.0828
epsilon <- 8.383e-08
gammaT <- 0.3568
gammaC <- 0.2654
thetaT <- 0.0767
thetaH <- 0.0154
thetaC <- 0.2096
S<- c()
It<- c()
Ih <- c()
C <- c()
Dt <- c()
Dh <- c()
Dc <- c()
Rt<- c()
Rc<- c()
S[1]<- N-383000-6300000-677000
It[1]<- 383000
Ih[1]<- 6300000
C[1]<- 677000
Dt[1] <- 0
Dh[1] <- 0
Dc[1] <- 0
Rt[1] <- 0
Rc[1] <- 0
for (j in 1:30) {
  S[j+1]<- S[j]+lambda*N-betaT*S[j]*It[j]/N-betaH*S[j]*Ih[j]/N-mu*S[j]
  It[j+1]<- It[j]+betaT*S[j]*It[j]/N-gammaT*It[j]-thetaT*It[j]-mu*It[j]
  Ih[j+1]<- Ih[j]+betaH*S[j]*Ih[j]/N-epsilon*It[j]*Ih[j]-thetaH*Ih[j]-mu*Ih[j]
  C[j+1]<- C[j]+epsilon*It[j]*Ih[j]-gammaC*C[j]-thetaC*C[j]-mu*C[j]
  Rt[j+1]<- Rt[j]+gammaT*It[j]-mu*Rt[j]
  Rc[j+1]<- Rc[j]+gammaC*C[j]-mu*Rc[j]
  Dt[j+1]<- Dt[j]+thetaT*It[j]
  Dh[j+1]<- Dh[j]+thetaH*Ih[j]
  Dc[j+1]<- Dc[j]+thetaC*C[j]
}
time<- 0:30

simulation <- data.frame(S,It,Ih,C,Dt,Dh,Dc,Rt,Rc,time)

#Figure 2a
library(ggplot2)
library("scales")
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = S)) + scale_y_continuous(labels = comma) + 
  labs(title="Susceptible population trajectory",
       x ="Year") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 2b
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = C, colour = "HIV+")) + 
  geom_line(aes(y = It, colour = "HIV-")) + scale_y_continuous(labels = comma) + 
  labs(title="TB infected population trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 3a
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = Ih)) + scale_y_continuous(labels = comma) + 
  labs(title="HIV infected population trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 3b
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = Rc, colour = "HIV+")) + 
  geom_line(aes(y = Rt, colour = "HIV-")) + scale_y_continuous(labels = comma) + 
  labs(title="TB recovery trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))

#Figure 4a
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = Dh)) + scale_y_continuous(labels = comma) + 
  labs(title="HIV death trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 4b
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = Dc, colour = "HIV+")) + 
  geom_line(aes(y = Dt, colour = "HIV-")) + scale_y_continuous(labels = comma) + 
  labs(title="TB death trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 5
ggplot(simulation, aes(time)) + geom_line(aes(y = Rc,colour = "Rc")) +
  geom_line(aes(y = It,colour = "It")) + geom_line(aes(y = Dc,colour = "Dc")) + 
  geom_line(aes(y = Rt,colour = "Rt")) + geom_line(aes(y = C,colour = "C")) + 
  geom_line(aes(y = Dt,colour = "Dt")) +scale_y_continuous(labels = comma) + 
  labs(title="TB Dynamics Trajectory",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 6a
simulation$TB <-NA
simulation$HIV <-NA
simulation$TB[1:8] <- c(simdata$C)
simulation$HIV[1:8] <- c(simdata$Ih)
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = TB, colour = "Obs")) + 
  geom_line(aes(y = C, colour = "Sim")) + scale_y_continuous(labels = comma) + 
  labs(title="Co-infected population trajectory(Observed vs. Simulated)",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))
#Figure 6b
ggplot(simulation, aes(time)) + 
  geom_line(aes(y = HIV, colour = "Obs")) + 
  geom_line(aes(y = Ih, colour = "Sim")) + scale_y_continuous(labels = comma) + 
  labs(title="HIV infected population trajectory(Observed vs. Simulated)",
       x ="Year", y = "Cases") +
  theme(plot.title = element_text(hjust = 0.5))

#Basic reproduction number
rot <- ((lambda*betaT)/(mu*(gammaT+thetaT+mu)))
roh <- ((lambda*betaH)/(mu*(thetaH+mu)))
